==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1StatusDetailsFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1StatusDetailsFluent<A extends V1StatusDetailsFluent<A>> extends Fluent<A>{


    public A addToCauses(int index,V1StatusCause item);
    public A setToCauses(int index,V1StatusCause item);
    public A addToCauses(V1StatusCause... items);
    public A addAllToCauses(Collection<V1StatusCause> items);
    public A removeFromCauses(V1StatusCause... items);
    public A removeAllFromCauses(Collection<V1StatusCause> items);
    
/**
 * This method has been deprecated, please use method buildCauses instead.
 * @return The buildable object.
 */
@Deprecated public List<V1StatusCause> getCauses();
    public List<V1StatusCause> buildCauses();
    public V1StatusCause buildCause(int index);
    public V1StatusCause buildFirstCause();
    public V1StatusCause buildLastCause();
    public V1StatusCause buildMatchingCause(io.kubernetes.client.fluent.Predicate<V1StatusCauseBuilder> predicate);
    public A withCauses(List<V1StatusCause> causes);
    public A withCauses(V1StatusCause... causes);
    public Boolean hasCauses();
    public V1StatusDetailsFluent.CausesNested<A> addNewCause();
    public V1StatusDetailsFluent.CausesNested<A> addNewCauseLike(V1StatusCause item);
    public V1StatusDetailsFluent.CausesNested<A> setNewCauseLike(int index,V1StatusCause item);
    public V1StatusDetailsFluent.CausesNested<A> editCause(int index);
    public V1StatusDetailsFluent.CausesNested<A> editFirstCause();
    public V1StatusDetailsFluent.CausesNested<A> editLastCause();
    public V1StatusDetailsFluent.CausesNested<A> editMatchingCause(io.kubernetes.client.fluent.Predicate<V1StatusCauseBuilder> predicate);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public Integer getRetryAfterSeconds();
    public A withRetryAfterSeconds(Integer retryAfterSeconds);
    public Boolean hasRetryAfterSeconds();
    public A withNewRetryAfterSeconds(int arg1);
    public A withNewRetryAfterSeconds(String arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();

    public interface CausesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1StatusCauseFluent<V1StatusDetailsFluent.CausesNested<N>>{

        
    public N and();    public N endCause();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1StatusDetailsFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1StatusDetailsFluent<A extends V1StatusDetailsFluent<A>> extends Fluent<A>{


    public A addToCauses(int index,V1StatusCause item);
    public A setToCauses(int index,V1StatusCause item);
    public A addToCauses(V1StatusCause... items);
    public A addAllToCauses(Collection<V1StatusCause> items);
    public A removeFromCauses(V1StatusCause... items);
    public A removeAllFromCauses(Collection<V1StatusCause> items);
    
/**
 * This method has been deprecated, please use method buildCauses instead.
 * @return The buildable object.
 */
@Deprecated public List<V1StatusCause> getCauses();
    public List<V1StatusCause> buildCauses();
    public V1StatusCause buildCause(int index);
    public V1StatusCause buildFirstCause();
    public V1StatusCause buildLastCause();
    public V1StatusCause buildMatchingCause(io.kubernetes.client.fluent.Predicate<V1StatusCauseBuilder> predicate);
    public Boolean hasMatchingCause(io.kubernetes.client.fluent.Predicate<V1StatusCauseBuilder> predicate);
    public A withCauses(List<V1StatusCause> causes);
    public A withCauses(V1StatusCause... causes);
    public Boolean hasCauses();
    public V1StatusDetailsFluent.CausesNested<A> addNewCause();
    public V1StatusDetailsFluent.CausesNested<A> addNewCauseLike(V1StatusCause item);
    public V1StatusDetailsFluent.CausesNested<A> setNewCauseLike(int index,V1StatusCause item);
    public V1StatusDetailsFluent.CausesNested<A> editCause(int index);
    public V1StatusDetailsFluent.CausesNested<A> editFirstCause();
    public V1StatusDetailsFluent.CausesNested<A> editLastCause();
    public V1StatusDetailsFluent.CausesNested<A> editMatchingCause(io.kubernetes.client.fluent.Predicate<V1StatusCauseBuilder> predicate);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(String arg1);
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public Integer getRetryAfterSeconds();
    public A withRetryAfterSeconds(Integer retryAfterSeconds);
    public Boolean hasRetryAfterSeconds();
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);

    public interface CausesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1StatusCauseFluent<V1StatusDetailsFluent.CausesNested<N>>{

        
    public N and();    public N endCause();
}


}
